diff --git a/Source/OpenTK/Math/Vector4.cs b/Source/OpenTK/Math/Vector4.cs
index c90f3882..f3f09e81 100644
--- a/Source/OpenTK/Math/Vector4.cs
+++ b/Source/OpenTK/Math/Vector4.cs
@@ -130,6 +130,19 @@ namespace OpenTK.Math
W = 0.0f;
}
+ ///
+ /// Constructs a new Vector4 from the specified Vector3 and W component.
+ ///
+ /// The Vector3 to copy components from.
+ /// The W component of the new Vector4.
+ public Vector4(Vector3 v, float w)
+ {
+ X = v.X;
+ Y = v.Y;
+ Z = v.Z;
+ W = w;
+ }
+
///
/// Constructs a new Vector4 from the given Vector4.
///
@@ -812,6 +825,14 @@ namespace OpenTK.Math
#endregion
+ #region Swizzle
+
+ public Vector2 Xy { get { return new Vector2(X, Y); } set { X = value.X; Y = value.Y; } }
+
+ public Vector3 Xyz { get { return new Vector3(X, Y, Z); } set { X = value.X; Y = value.Y; Z = value.Z; } }
+
+ #endregion
+
#region Operators
public static Vector4 operator +(Vector4 left, Vector4 right)
diff --git a/Source/OpenTK/Math/Vector4d.cs b/Source/OpenTK/Math/Vector4d.cs
index 1db2bdde..29d1694d 100644
--- a/Source/OpenTK/Math/Vector4d.cs
+++ b/Source/OpenTK/Math/Vector4d.cs
@@ -104,10 +104,10 @@ namespace OpenTK.Math
}
///
/// Constructs a new Vector4d from the given Vector2.
///
- /// The Vector2 to copy components from.
- public Vector4d(Vector2 v)
+ /// The Vector2d to copy components from.
+ public Vector4d(Vector2d v)
{
X = v.X;
Y = v.Y;
@@ -116,10 +116,10 @@ namespace OpenTK.Math
}
///
/// Constructs a new Vector4d from the given Vector3.
///
- /// The Vector3 to copy components from.
- public Vector4d(Vector3 v)
+ /// The Vector3d to copy components from.
+ public Vector4d(Vector3d v)
{
X = v.X;
Y = v.Y;
@@ -127,6 +127,19 @@ namespace OpenTK.Math
W = 0.0f;
}
+ ///
+ /// Constructs a new Vector4d from the specified Vector3d and W component.
+ ///
+ /// The Vector3d to copy components from.
+ /// The W component of the new Vector4.
+ public Vector4d(Vector3 v, double w)
+ {
+ X = v.X;
+ Y = v.Y;
+ Z = v.Z;
+ W = w;
+ }
+
///
/// Constructs a new Vector4d from the given Vector4d.
///
@@ -104,10 +104,10 @@ namespace OpenTK.Math
}
///
- /// Constructs a new Vector4d from the given Vector2.
+ /// Constructs a new Vector4d from the given Vector2d.
///
@@ -116,10 +116,10 @@ namespace OpenTK.Math
}
///
- /// Constructs a new Vector4d from the given Vector3.
+ /// Constructs a new Vector4d from the given Vector3d.
///